:- multifile word/2.


:- ensure_loaded('scp2.pl').
:- ensure_loaded('pronto_morph_engine.pl').
:- ensure_loaded('cclalt.pl').
:- ensure_loaded('lexicon2.gmr').
:- ensure_loaded('rules.gmr').
:- ensure_loaded('et.pl').



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Predicates that call the FSA
%%
%%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%












%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Predicates for files formatted by sentence
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




% rank a single sentence from all appropriate templates
rank_a_sentence(String,Templates) :-
    get_patterns(Templates,Patterns),
    get_children,
    rank_lists(Patterns,[String]).

rank_sentence_file(File,Templates,OutFile) :-
    tell(OutFile),
    rank_sentences(File,Templates),
	flush,
    told.

% rank all the sentences in a set of files and output the results to a file.
rank_sentences_files(TempFile,Templates,OutFile) :-
   ensure_loaded(TempFile),
   get_patterns(Templates,Patterns),
   get_children,
   tell(OutFile),
   rank_sentences_files_aux(Patterns,1),
	flush,
   told.


rank_sentences_files_aux(Patterns,Num) :-
   file_loc(Num,1,FileName),!,
   open(FileName,read,Stream),
   get_lists(Stream,Lists),
   close(Stream),
   write('file: '),write(FileName),nl,
   rank_lists(Patterns,Lists),
   Num2 is Num+1,
   rank_sentences_files_aux(Patterns,Num2).

rank_sentences_files_aux(Patterns,Num) :-
	file_loc(Num,0,_),!,
	Num2 is Num+1,
	rank_sentences_files_aux(Patterns,Num2).

rank_sentences_files_aux(Patterns,Num) :-
	files(X),
	Num < X,
	Num2 is Num+1,
	rank_sentences_files_aux(Patterns,Num2).


rank_sentences_files_aux(_,_).


% rank each line of a single file separately.  returns all of the rankings it found at each level
rank_sentences(FileName,Templates) :-
   get_patterns(Templates,Patterns),
   get_children,
   open(FileName,read,Stream),
   get_lists(Stream,Lists),
   close(Stream),
   rank_lists(Patterns,Lists).

get_lists(Stream,[]) :-
   peek_code(Stream,X),
   X == -1.

get_lists(Stream,[Words|Lists]) :-
   tokenize_line(Stream,Line),
   tokens_words(Line,Words),
   get_lists(Stream,Lists).

rank_lists(_,[]) :- nl,nl,nl,nl,nl.


% Input is a list of Patterns and a List of items to be ranked.  Ouput is a printed list of the ranks of the items
rank_lists(Patterns,[H|Tail]) :-
   write('sentence: '),write(H),nl,
   rank_text_aux_alt(Patterns,H,0,TotalScore,ScoreList),
   write('line total score: '),write(TotalScore),nl,
   print_scores(ScoreList),
   rank_lists(Patterns,Tail).

print_scores([]).

print_scores([(Level,Score)|Tail]) :-
   write('score level: '),write(Level),write(' score: '),write(Score),nl,
   print_scores(Tail).



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% SAS Format Output
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



rank_files_to_sas(TempFile,TemplateFile,OutFile) :-
	get_patterns(TemplateFile,Patterns),
	ensure_loaded(TempFile),
	tell(OutFile),
	rank_files_to_sas_aux(1,Patterns),
	flush,
	told.

rank_files_to_sas_aux(Num,Patterns) :-
	file_loc(Num,1,FileName),
	write(FileName),nl,
	rank_text_sas(FileName,Patterns,0,_),
	Num2 is Num + 1,
	rank_files_to_sas_aux(Num2,Patterns).

rank_files_to_sas_aux(Num,Patterns) :-
	file_loc(Num,0,_),
	Num2 is Num + 1,
	rank_files_to_sas_aux(Num2,Patterns).

rank_files_to_sas_aux(Num,Patterns) :-
	files(X),
	Num < X,
	Num2 is Num + 1,
	rank_files_to_sas_aux(Num2,Patterns).

rank_files_to_sas_aux(_,_).






% ranks a text and outputs results in SAS readable format
rank_text_sas(FileName,[(Level,TemplateHead)|Tail],Score,TotalScore) :-
   tokenize_file(FileName,TokenList),
   tokens_words(TokenList,WordList),
   get_children,
   rank_text_sas_aux_alt([(Level,TemplateHead)|Tail],WordList,Score,TScore,ScoreList),
   length(WordList,Length),
   TotalScore is TScore/Length,
	print_score_list_sas(Length,ScoreList),
	write(TotalScore),nl. % score is the raw score over the number of words in the text.

rank_text_sas_aux_alt([],_,Score,Score,[]) :- !.

rank_text_sas_aux_alt([(Level,TemplateHead)|Tail],WordList,Score,TScore,[(L2,S)|Rest]) :-
	run_fsa_alt(TemplateHead,WordList,0,S),
	NewScore is Score + (S*Level),
	L2= Level,
	rank_text_sas_aux_alt(Tail,WordList,NewScore,TScore,Rest).

% collect a list of levels and how many of each there are
rank_text_sas_aux([],_,[]) :- !.

rank_text_sas_aux([(Level,TemplateHead)|Tail],WordList,[(Level,S)|Rest]) :-
    run_fsa_alt(TemplateHead,WordList,0,S),
    rank_text_sas_aux(Tail,WordList,Rest).


print_score_list_sas(_,[]).

print_score_list_sas(Length,[(Level,Score)|Tail]) :-
   S is (Level*Score)/Length,
   write(S),write(' '),
   print_score_list_sas(Length,Tail).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% rank all the sentences from a series of files and print the results in a sas-ready format
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

rank_sentences_sas(FileName,Templates,OutFile) :-
   get_patterns(Templates,Patterns),
   get_children,
    ensure_loaded(FileName),
    tell(OutFile),
   rank_sentences_sas_aux(1,Patterns),
	flush,
    told.


rank_sentences_sas_aux(Count,Patterns) :-
    file_loc(Count,1,FileName),
    open(FileName,read,Stream),
    get_lists(Stream,Lists),
    close(Stream),
    write('* '),write(FileName),nl,
    rank_lists_sas(Patterns,Lists),!,
    C2 is Count + 1,
    rank_sentences_sas_aux(C2,Patterns).

rank_sentences_sas_aux(Count,Patterns) :-
	file_loc(Count,0,_),
	C2 is Count + 1,
	rank_sentences_sas_aux(C2,Patterns).

rank_sentences_sas_aux(Count,Patterns) :-
	Count < 30,
	C2 is Count + 1,
	write('not to be ranked'),nl,
	rank_sentences_sas_aux(C2,Patterns).

rank_sentences_sas_aux(_,_) :- !.

rank_lists_sas(_,[]) :- !.


% Input is a list of Patterns and a List of items to be ranked.  Ouput is a printed list of the ranks of the items
rank_lists_sas(Patterns,[H|Tail]) :-
   length(H,Len),
   Len > 0,
   % write(H),nl,
   write(Len),write(' '),!,
   rank_text_sas_aux(Patterns,H,ScoreList),
   print_scores_sas(ScoreList,Len),nl,
   rank_lists_sas(Patterns,Tail).

rank_lists_sas(Patterns,[H|Tail]) :-
   H == 0,!,
   rank_lists_sas(Patterns,Tail).

rank_lists_sas(_,_) :-
	nl,write('failed to rank text or print scores'),nl.

% print the scores of each structure found in a sentence
print_scores_sas([],_) :- !.

print_scores_sas([(_,Count)|T],Len) :-
    Score is Count,


    write(Score),write(' '),
    print_scores_sas(T,Len).

/*
print_scores_sas([(_,Count)|T]) :-
    Count == 0,
    write(0),write(' '),
    print_scores_sas(T).
*/
pss_alt(_,0).

pss_alt(Level,Count) :-
    write(Level),write(' '),
    C2 is Count - 1,
    pss_alt(Level,C2).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Unformatted Text File Predicates
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


rank_files_to_file(TempFile,TemplateFile,OutFile) :-
   	tell(OutFile),
   	get_patterns(TemplateFile,Patterns),
	ensure_loaded(TempFile),
   	rank_files_to_file_aux(1,Patterns),
	flush,
   	told.

rank_files_to_file_aux(Num,Patterns) :-
	file_loc(Num,1,FileName),
  	write('file: '),write(FileName),nl,
   	rank_text_alt(FileName,Patterns,0,Score),
   	write('total score: '),write(Score),nl,
   	Num2 is Num + 1,
   	rank_files_to_file_aux(Num2,Patterns).

rank_files_to_file_aux(Num,Patterns) :-
	file_loc(Num,0,_),
	Num2 is Num + 1,
	rank_files_to_file_aux(Num2,Patterns).

rank_files_to_file_aux(Num,Patterns) :-
	files(X), 
	Num < X,
	Num2 is Num + 1,
	rank_files_to_file_aux(Num2,Patterns).

rank_files_to_file_aux(_,_).


rank_from_templates_score_list(FileNum,TempFile,TemplateFile,Score) :-
   get_patterns(TemplateFile,Patterns),
   get_file_location(FileNum,TempFile,FileName),
   rank_text_alt(FileName,Patterns,0,Score).

% like rank_from_templates but accesses the files in a different way.
% uses a file template.
rank_from_templates(FileNum,TempFile,TemplateFile,Score) :-
   get_patterns(TemplateFile,Patterns),
   get_file_location(FileNum,TempFile,FileName),
   rank_text(FileName,Patterns,0,Score).

% consult a template file for the patterns used to rank the text
rank_from_templates(FileName,TemplateFile,Score) :-
   get_patterns(TemplateFile,Patterns),
   rank_text(FileName,Patterns,0,Score).


% checks to see if a list of atoms matches the given template.
rank_atoms(List,Template,Score) :-
   get_children,
   run_fsa(Template,List,0,Score).

% get_patterns from a file of template/2 clauses
get_patterns(FileName,PatternList) :-
   ensure_loaded(FileName),
   findall((X,Y),template(X,Y),PatternList).

get_file_location(Num,FileName,FileLocation) :-
   ensure_loaded(FileName),
   file_loc(Num,1,FileLocation).


rank_single_level(FileNum,FilesFile,Template,Score) :-
   get_file_location(FileNum,FilesFile,FileName),
   rank_text(FileName,[(1,Template)],0,Score).


% finds all occurrences of a given template in the given file
rank_single_level(FileName,Template,Score) :-
   tokenize_file(FileName,TokenList),
   tokens_words(TokenList,WordList),
   get_children,
   run_fsa(Template,WordList,0,Score).


% determines syntactic comlexity of a text by running through a file and finding all occurrences of all the provided templates and
% returns a score
rank_text(FileName,[(Level,TemplateHead)|Tail],Score,TotalScore) :-
   tokenize_file(FileName,TokenList),
   tokens_words(TokenList,WordList),
   get_children,
   rank_text_aux([(Level,TemplateHead)|Tail],WordList,Score,TScore),
   length(WordList,Length),
   TotalScore is TScore/Length. % score is the raw score over the number of words in the text.

rank_text_aux([],_,Score,Score) :- !.

rank_text_aux([(Level,TemplateHead)|Tail],WordList,Score,TotalScore) :-
   write('level: '),write(Level),nl,write('template: '),write(TemplateHead),nl,
   run_fsa(TemplateHead,WordList,0,S),
   NewScore is Score+(S*Level),
   rank_text_aux(Tail,WordList,NewScore,TotalScore).





% gets a list of the scores of each level and prints it out.  scores for each level are calculated the same as scores for the whole text.
rank_text_alt(FileName,[(Level,TemplateHead)|Tail],Score,TotalScore) :-
   tokenize_file(FileName,TokenList),
   tokens_words(TokenList,WordList),
   get_children,
   rank_text_aux([(Level,TemplateHead)|Tail],WordList,Score,TScore,ScoreList),
   length(WordList,Length),
   TotalScore is TScore/Length,
   print_score_list(Length,ScoreList).



print_score_list(_,[]).

print_score_list(Length,[(Level,Score)|Tail]) :-
   S is (Level*Score)/Length,
   write('score level '),write(Level),write(': '),write(S),nl,
   print_score_list(Length,Tail).



rank_text_aux_alt([],_,Score,Score,[]) :- !.



rank_text_aux_alt([(Level,TemplateHead)|Tail],WordList,Score,TotalScore,[(Level,S)|Rest]) :-
   run_fsa(TemplateHead,WordList,0,S),
   % write('run fsa score: '),write(S),nl,
   S \== 0,!,
   write('level: '),write(Level),nl,write('template: '),write(TemplateHead),nl,
   NewScore is Score+(S*Level),
   rank_text_aux_alt(Tail,WordList,NewScore,TotalScore,Rest).

rank_text_aux_alt([_|Tail],WordList,Score,TotalScore,Rest) :-
   !,
   rank_text_aux_alt(Tail,WordList,Score,TotalScore,Rest).


% an alternate version of rank text aux that returns a list of scores at each level
rank_text_aux([],_,Score,Score,[]) :- !.

rank_text_aux([(Level,TemplateHead)|Tail],WordList,Score,TotalScore,[(Level,S)|Rest]) :-
   write('level: '),write(Level),nl,write('template: '),write(TemplateHead),nl,
   run_fsa(TemplateHead,WordList,0,S),
   NewScore is Score+(S*Level),
   rank_text_aux(Tail,WordList,NewScore,TotalScore,Rest).

rank_files_sas_scores(Files,Templates,OutFile) :-
	get_patterns(Templates,Patterns),
	ensure_loaded(Files),
	tell(OutFile),
	rank_files_sas_scores_aux(1,Patterns),
	flush,
	told.

	


rank_files_sas_scores_aux(Num,Patterns) :-
	file_loc(Num,1,FileName),
	rank_text_sas2(FileName,Patterns,0,Score),
	write(FileName),write(' '),write(Score),nl,
	Num2 is Num + 1,
	rank_files_sas_scores_aux(Num2,Patterns).

rank_files_sas_scores_aux(Num,Patterns) :-
	file_loc(Num,0,_),
	Num2 is Num + 1,
	rank_files_sas_scores_aux(Num2,Patterns).

rank_files_sas_scores_aux(Num,Patterns) :-
	files(X),
	Num < X,
	Num2 is Num + 1,
	rank_files_sas_scores_aux(Num2,Patterns).

rank_files_sas_scores_aux(_,_).

rank_text_sas2(FileName,[(Level,TemplateHead)|Tail],Score,TotalScore) :-
   tokenize_file(FileName,TokenList),
   tokens_words(TokenList,WordList),
   get_children,
   rank_text_sas2_aux([(Level,TemplateHead)|Tail],WordList,Score,TScore),
   length(WordList,Length),
   TotalScore is TScore/Length. % score is the raw score over the number of words in the text.

rank_text_sas2_aux([],_,Score,Score) :- !.

rank_text_sas2_aux([(Level,TemplateHead)|Tail],WordList,Score,TotalScore) :-
   run_fsa_alt(TemplateHead,WordList,0,S),
   NewScore is Score+(S*Level),
   rank_text_sas2_aux(Tail,WordList,NewScore,TotalScore).



run_fsa_alt(_,[],Score,Score) :- !.

% runs through the FSA. returns score for one level
run_fsa_alt(Pattern,String,Score,TotalScore) :-
    fsa(Pattern,String,Rest,S,_),!,
    NewScore is Score + S,
    run_fsa_alt(Pattern,Rest,NewScore,TotalScore).






% resets and runs the fsa every time a part of the string matching the given pattern is found.
run_fsa(_,[],Score,Score) :- !.

run_fsa(Pattern,String,Score,TotalScore) :-
   fsa(Pattern,String,Rest,S,Phrase),
   NewScore is Score + S,
   ((S == 1,
   write('phrase: '),write(Phrase),write(' '),write('count: '),write(NewScore),nl)
   ;
   true),!,
   run_fsa(Pattern,Rest,NewScore,TotalScore).

% run_fsa(_,_,Score,Score).






%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% the fsa
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% this is a redo of the FSA portion of my thesis.  It makes several improvements:
% - it only chunk parses prepositional, adverbial, and adjectival phrases
% - it skips over those phrases
% - it checks for patterns of words instead of phrases
% - some words must immediately be followed by others. some words can have phrases between them.


:- dynamic child_of/2.
% fsa(+Points,+Pattern,+String,-Rest,+Phrase,-CompletePhrase)
% accepts a pattern and a string of text.  Succeeds if the Pattern is found in the String. Returns the Rest of the String. Returns a 1
% to indicate a successful find or a 0 to indicate an unsuccessful find.
% fsa returns the string it found upon completing an analysis (CompletePhrase)

% no more Pattern.  Return what's left of the String.
fsa([],String,String,1,[]) :- !.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% beginning of the string rules
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
/*
% the current word in the input stream is an adjective. Parse a chunk and move past it.
fsa([-|T],[Adj|Tail],Rest,Score,[[Adj2]|Phrase]) :-
   (word(adj,Adj)
   ;
   (word(Cat,Adj),
   child_of(Cat,adjp))),!,
   Adj2= Adj,
   fsa(T,Tail,Rest,Score,Phrase).

% the current word in the input stream is an adverb.  Parse a chunk and move past it.
fsa([-|T],[Adv|Tail],Rest,Score,[[Adv2]|Phrase]) :-
   (word(adv,Adv)
   ;
   (word(Cat,Adv),
   child_of(Cat,advp))),!,
   Adv2= Adv,
   fsa(T,Tail,Rest,Score,Phrase).
*/





%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% find particular word
%%%%%%%%%%%%%%%%%%%%%%%%%%%
fsa([Word|T],[Word|Tail],Rest,Score,[W|Phrase]) :-
   W= Word,!,
   fsa(T,Tail,Rest,Score,Phrase).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% beginning of phrase special cases
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fsa([-,Word|T],[Word|Tail],Rest,Score,[W|Phrase]) :-
   W= Word,!,
   fsa(T,Tail,Rest,Score,Phrase).


% beginning of phrase skip a prepositional phrase.  Since its at the beginning don't add it in.
fsa([-|T],[pp(_)|Tail],Rest,Score,Phrase) :-
   !,
   fsa([-|T],Tail,Rest,Score,Phrase).

fsa([-,subconj|_],[for,a,while|Tail],Tail,0,[]) :- !.

fsa([-,subconj|_],[for,example|Tail],Tail,0,[]) :- !.


fsa([-,subconj|_],[for,sure|Tail],Tail,0,[]) :- !.

fsa([-,subconj|_],[for,certain|Tail],Tail,0,[]) :- !.

fsa([-,subconj|_],[for,the,time,being|Tail],Tail,0,[]) :- !.

fsa([-,subconj|_],[as,normal|Tail],Tail,0,[]) :- !.

fsa([-,subconj|_],[as,usual|Tail],Tail,0,[]) :- !.

fsa([-,subconj|_],[as,per,usual|Tail],Tail,0,[]) :- !.


% there are execptions to this
fsa([-,subconj_],[and,so,on|Tail],Tail,0,[]) :- !.

% there are many exceptions to this pattern
fsa([-,subconj|_],[like,that|Tail],Tail,0,[]) :- !.




fsa([-,subconj|_],[Adj1,Adj2|Tail],Tail,0,[]) :-
   word(adj,[Adj1,Adj2]), !.

fsa([-,subconj|_],[Word,that|Tail],Tail,0,[]) :-
   member(Word,[such,like]), !.

fsa([-,subjconj|_],[that,is|Tail],Tail,0,[]) :- !.

fsa([-,subconj|_],[as,Adj,as|Tail],Tail,0,[]) :-
   word(adj,Adj),!.


% tries to handle 'in case of outbreaks' and similar sentences
% misses 'in case of all
fsa([-,subconj|_],[W1,W2,P|Tail],Tail,0,[]) :-
   word(subconj,[W1,W2]),
   word(p,P),!.


/*
% quick and dirty fix mostly for the verb 'have'
fsa([-,vnfc|_],[V1,V2|Tail],Tail,0,[]) :-
   word(vnfc,V1),
   word(adj,V2),
   word(vppl,V2).
*/

% quick and dirty fix mostly for the verb 'have'
fsa([-,vnfc|_],[V1,V2|Tail],Tail,0,[]) :-
   word(vnfc,V1),
   word(adj,V2),
   word(vpsed,V2),!.

% fsa wants vpsed.  the current word is a noun. the next word is a candidate, but has a noun form.  assume the second word is a noun.
fsa([-,vnfc|_],[N1,N2|Tail],Tail,0,[]) :-
   word(n,N1),
   \+ word(npl,N1),
   word(vnfc,N2),
   word(n,N2),!.

% fsa wants a vpsed. the current word is a candidate. the next word is an auxiliary verb.  assume the current word isn't a verb.
fsa([-,vnfc|_],[V1,V2|T],[V2|T],0,[]) :-
   word(vnfc,V1),
   word(vaux,V2),
   word(X,V1),
   child_of(X,dp),!.


% beginning of phrase
% fsa wants a vpsed. the word befor a candidate verb is a determiner. assume candidate is not a verb. quit.
% trouble sentence: "this used to be..." "that seems to be..." "
fsa([-,vnfc|_],[V0,V1|T],T,0,[]) :-
   word(d,V0),
   \+ word(pronoun,V0),
   word(vnfc,V1),
   \+ word(adj,V1),!.


% fsa wants a vpsed. the word before a candidate verb is a determiner. assume candidate is not a verb. quit.
fsa([-,vnfc|_],[V0,V1|T],T,0,[]) :-
   word(adj,V0),
   \+ word(adv,V0),
   word(vnfc,V1),
   \+ word(adj,V1),!.

% if you have a preposition followed by a verb in -ing form, don't parse the preposition, instead accept the verb
fsa([-,vnfc|T],[P,V|Tail],Rest,Score,[V2|Phrase]) :-
   word(p,P),
   word(vnfc,V),
   word(ving,V),!,
   V2= V,
   fsa(T,Tail,Rest,Score,Phrase).

% if you are looking for a verb and see an "s" with two nouns around it it's not a verb, its a possessive
% skip onto the next parts
fsa([-,vpsed|T],[W1,s,W2|Tail],Rest,Score,Phrase) :-
   word(n,W1),
   word(n,W2),!,
   fsa([-,vpsed|T],Tail,Rest,Score,Phrase).




% fsa wants vpsed.  the current word is a noun. the next word is a candidate, but has a noun form.  assume the second word is a noun.
fsa([-,vpsed|_],[N1,N2,N3|Tail],Tail,0,[]) :-
   word(n,N1),
   word(vpsed,N2),
   word(n,N2),
   N3 \== to,!.

% fsa wants a vpsed. the current word is a candidate. the next word is an auxiliary verb.  assume the current word isn't a verb.
fsa([-,vpsed|_],[V1,V2|T],[V2|T],0,[]) :-
   word(vpsed,V1),
   word(vaux,V2),
   word(X,V1),
   child_of(X,dp),!.


% beginning of phrase
% fsa wants a vpsed. the word befor a candidate verb is a determiner. assume candidate is not a verb. quit.
% trouble sentence: "this used to be..." "that seems to be..." "
fsa([-,vpsed|_],[V0,V1|T],T,0,[]) :-
   word(d,V0),
   \+ word(pronoun,V0),
   word(vpsed,V1),
   \+ word(adj,V1),!.


% fsa wants a vpsed. the word before a candidate verb is a determiner. assume candidate is not a verb. quit.
fsa([-,vpsed|_],[V0,V1|T],T,0,[]) :-
   word(adj,V0),
   word(vpsed,V1),
   \+ word(adj,V1),!.

% you are at the beginning of the stream.
% fsa wants a vpsed.  accept if the next word is not an auxillary verb and the previous word isn't a determiner
fsa([-,vpsed|T],[V0,V1,V2|Tail],Rest,Score,[V3|T1]) :-
   \+ word(d,V0),
   \+ word(pronoun,V0),
   \+ word(p,V0),
   word(vpsed,V1),
   \+ word(vaux,V2),
   \+ word(vpsed,V2),
   !,
   V3= V1,
   fsa(T,[V2|Tail],Rest,Score,T1).

% fsa looking for a noun.  if the current word is a noun but not a pronoun, and the next word is also part of a noun phase, skip it.
fsa([-,n|T],[N1,N2|Tail],Rest,Score,[[N3]|Phrase]) :-
   N1 \== that,
   N2 \== that,
   word(C1,N1),
   C1 \== pronoun,
   child_of(C1,dp),
   word(C2,N2),
   C2 \== d,
   \+ word(p,N2),
   child_of(C2,dp),
   !,
   N3= N1,
   fsa([-,n|T],[N2|Tail],Rest,Score,Phrase).

% beginning of pattern
% skip determiners
fsa([-,n|T],[D|Tail],Rest,Score,[[D1]|Phrase]) :-
   word(d,D),
   \+ word(n,D),
   D1= D,
   !,
   fsa([-,n|T],Tail,Rest,Score,Phrase).

% at beginning of pattern
% accept a pronoun as a noun if the next word is not part of a noun phrase.
fsa([-,n|T],[Pr|Tail],Rest,Score,[Pr2|Phrase]) :-
   word(pronoun,Pr),
   Pr2= Pr,!,
   fsa(T,Tail,Rest,Score,Phrase).

fsa([-,X|T],[W1,W2,W3|Tail],Rest,Score,[W4,W5,W6|Phrase]) :-
   find_element(X,[W1,W2,W3]),!,
   W4= W1,
   W5= W2,
   W6= W3,
   fsa(T,Tail,Rest,Score,Phrase).

fsa([-,X|T],[W1,W2|Tail],Rest,Score,[W3,W4|Phrase]) :-
   find_element(X,[W1,W2]),!,
   W3= W1,
   W4= W2,
   fsa(T,Tail,Rest,Score,Phrase).


% the fsa is at the beginning at the current element in the stream doesn't match what the fsa is looking for
fsa([-,E|T],[H|Tail],Rest,Score,[H2|Phrase]) :-
   find_element(E,H),
   H2= H,!,
   fsa(T,Tail,Rest,Score,Phrase).

% The current word is a pp. it is followed by a determiner or a plural noun. skip the pp.
fsa([-|T],[PP,D|Tail],Rest,Score,Phrase) :-
   word(p,PP),
   (word(d,D)
   ;
   (PP \== to,
   word(n,D))
   ;
   (PP == to,
   \+ word(v,D))
   ;
   word(npl,D)
   ),
   parse(pp,[PP,D|Tail],Remain,Words,_),!,
   fsa([-|T],[pp(Words)|Remain],Rest,Score,Phrase).

% didn't find the initial element
fsa([-,E|T],[_|Tail],Rest,Score,Phrase) :-
   !,
   fsa([-,E|T],Tail,Rest,Score,Phrase).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% comp rules
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

fsa([comp|_],[Comp,s|Tail],Tail,0,[]) :-
   word(comp,Comp),!.

% if you see a comp followed by a singular noun  assume the comp is a determiner and quit
% this makes errors: ie 'i think that fish is a tasty food'
% MontyTagger also makes this mistake
fsa([comp|_],[Comp,N|Tail],Tail,0,[]) :-
    word(comp,Comp),
    word(d,Comp),
    word(nsg,N),
    \+ word(pronoun,N),!.





%%%%%%%%%%%%%%%%%%%%%%%
% rules for skipping pps
%%%%%%%%%%%%%%%%%%%%%%%

% don't allow pp before a comp
fsa([comp|_],[pp([P|_]),W2|Tail],Tail,0,[pp,W3]) :-
   P \== of,
   word(comp,W2),!,
   W3= W2.

% skip pps otherwise
fsa(Pattern,[pp(W)|Tail],Rest,Score,[Words|T]) :-
   !,
   Words= W,
   fsa(Pattern,Tail,Rest,Score,T).

% special case for 'so that'.  real clumsy but i want it fixed now.
fsa([comp|_],[so,that|Tail],Tail,0,[]) :- !.

fsa([comp|T],[W1,W2|Tail],Rest,Score,[W3,W4|Phrase]) :-
    word(comp,[W1,W2]),
    W3= W1,
    W4= W2,
    !,
    fsa(T,Tail,Rest,Score,Phrase).


% looking for a comp.  see an adjective before a comp.  quit.
fsa([comp|_],[W1,W2|Tail],Tail,0,[]) :-
   word(adj,W1),
   word(comp,W2),!.



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% rules for skipping adjps
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
/*
% fail if you get an adjective that's not an ing verb after a be verb
fsa(_,[W1,W2|T],T,0,[W3]) :-
   W1 \== be,
   word(bev,W1),
   word(adj,W2),
   \+ word(ving,W2),
   !,
   W3= W1.
*/

%%%%%%%%%%%%%%%%%%%%%%
% verb special cases
%%%%%%%%%%%%%%%%%%%%%%

fsa([to,vpl],[Adj,to,V1|T],T,0,[]) :-
   word(adj,Adj),
   word(vpl,V1),!.


% don't accept an adjective before an ing verb
fsa([ving|T],[Adj,V|T],T,0,[]) :-
   word(adj,Adj),
   word(ving,V),!.

% some adjective s are also determiners.  don't skip these.
% if it is not an adjective, quit
fsa([vpsed|_],[Adj,Word|Tail],Tail,0,[]) :-
   word(adj,Adj),
   word(d,Adj),
   word(vpsed,Word),
   word(n,Word),!.

% some adjective s are also determiners.  don't skip these.
% if it is not an adjective, quit
fsa([ving|_],[Adj,Word|Tail],Tail,0,[]) :-
   word(adj,Adj),
   word(d,Adj),
   word(ving,Word),
   word(n,Word),!.


% if you are looking for a verb and see an "s" with two nouns around it it's not a verb, its a possessive
fsa([vnfc|_],[W1,s,W2|T],T,0,[]) :-
   word(n,W1),
   word(n,W2),!.

fsa([vpsed|_],[W1,s,W2|T],T,0,[]) :-
   word(n,W1),
   word(n,W2),!.

fsa([ving|_],[W1,s,W2|T],T,0,[]) :-
   word(n,W1),
   word(n,W2),!.

% fsa wants a vpsed. the current word is a candidate. the next word is an auxiliary verb.  assume the current word isn't a verb.
fsa([vpsed|_],[V1,V2|T],T,0,[]) :-
   word(vpsed,V1),
   word(vaux,V2),
   word(X,V1),
   child_of(X,dp),!.

% fsa wants a vpsed. the word before a candidate verb is a determiner. assume candidate is not a verb. quit.
fsa([vpsed|_],[V0,V1|T],T,0,[]) :-
   word(d,V0),
   word(vpsed,V1),!.


% fsa wants a vpsed. the word before a candidate verb is a determiner. assume candidate is not a verb. quit.
fsa([vpsed|_],[V0,V1|T],T,0,[]) :-
   word(adj,V0),
   word(vpsed,V1),!.


% if you have a preposition followed by a verb in -ing form, don't parse the preposition, instead accept the verb

fsa([vnfc|T],[P,V|Tail],Rest,Score,[V2|Phrase]) :-
   word(p,P),
   word(vnfc,V),
   word(ving,V),!,
   V2= V,
   fsa(T,Tail,Rest,Score,Phrase).


% fsa is looking for a verb of a certain kind.  if the next word is a verb, skip the current word if it is an auxiliary or a child of a auxp
fsa([H|T],[V1,V2|Tail],Rest,Score,[[V3]|Phrase]) :-
   member(H,[vpsed,ving]),
   word(vaux,V1),
   (word(v,V2)
   ;
   word(vpsed,V2)
   ;
   word(vaux,V2)
   ;
   (word(X,V2),
   child_of(X,advp))),!,
   V3= V1,
   fsa([H|T],[V2|Tail],Rest,Score,Phrase).




% verb, followed by adverb then accept the verb.
fsa([vpsed|T],[V1,Adv|Tail],Rest,Score,[V2|Phrase]) :-
   word(vpsed,V1),
   word(adv,Adv),!,
   V2= V1,
   fsa(T,[Adv|Tail],Rest,Score,Phrase).



fsa([vpsed|T],[C|Tail],Rest,Score,[C2|Phrase]) :-
   find_element(vpsed,C),
   !,
   C2= C,
   fsa(T,Tail,Rest,Score,Phrase).


% fsa is looking for a verb in plain, -s, or -ed form, but the current word is not it.  The current word is a part
% of a verb phrase so move past it.
fsa([vpsed|T],[V|Tail],Rest,Score,[[V2]|Tl]) :-
   word(Cat,V),
   (child_of(Cat,vp)
   ;
   child_of(Cat,auxp)),!,
   V2= V,
   fsa([vpsed|T],Tail,Rest,Score,Tl).












%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% noun special cases
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


fsa([n|_],[N1,N2|Tail],Tail,0,[]) :-
    (N1 == that
    ;
    N2 == that),!.

% might add some rules here that look at the different types of words that follow nouns.

% if you have a word you think is a noun, if the next word is a verb and the noun is also a verb or aux verb then
% you are done parsing nouns
fsa([n|T],[n(N),V|Tail],Rest,Score,Phrase) :-
    (word(vpsed,N)
    ;
    word(vaux,N)),
    (word(vpsed,V)
    ;
    word(vaux,N)),!,
    fsa(T,[N,V|Tail],Rest,Score,Phrase).


% if you have a word you know is a noun followed by another that looks like it, label the possible as a noun
fsa([n|T],[n(N),N2|Tail],Rest,Score,[N1|Phrase]) :-
    word(n,N2),!,
    N1= N,
    fsa([n|T],[n(N2)|Tail],Rest,Score,Phrase).


% if you have a word you labeled as a noun, and you're looking for a noun, then accept the labeled one
fsa([n|T],[n(N)|Tail],Rest,Score,[N1|Phrase]) :-
    N1= N,!,
    fsa(T,Tail,Rest,Score,Phrase).


% if you have a candidate noun followed by a complementizer followed by a noun phrase, your first noun probably isn't one
fsa([n|_],[N,Comp,Det|T],T,0,[]) :-
   word(n,N),
   word(ving,N),
   word(comp,Comp),
   word(d,Det),!.



% if you havea pronoun followed by a verb, but are looking for two nouns, then quit.
fsa([n,n|_],[Pr,Vb|Tail],Tail,0,[]) :-
   word(pronoun,Pr),
   word(v,Vb),!.

% accept a pronoun as a noun if the next word is not part of a noun phrase.
fsa([n|T],[Pr,Vb|Tail],Rest,Score,[Pr2|Phrase]) :-
   word(pronoun,Pr),
   word(v,Vb),
   \+ word(n,Vb),!,
   Pr2= Pr,
   fsa(T,[Vb|Tail],Rest,Score,Phrase).

% if you see a plural noun followed by a singualar noun, then accept the plural and move to detect the next element
fsa([n|T],[N1,N2|Tail],Rest,Score,[N3|Phrase]) :-
    word(npl,N1),
    word(nsg,N2),!,
    N3= N1,
    fsa(T,[N2|Tail],Rest,Score,Phrase).


% fsa looking for a noun.  if the current word is a noun but not a pronoun, and the next word is also part of a noun phase, skip it.
% temp fix: we s
fsa([n|T],[N1,N2|Tail],Rest,Score,[[N3]|Phrase]) :-
   (word(n,N1)
   ;
   word(conj,N1)),
   (word(n,N2)
   ;
   word(conj,N2)),
   !,
   N3= N1,
   fsa([n|T],[N2|Tail],Rest,Score,Phrase).


% skip determiner and adjective if the adjective can also be a preposition
fsa([n|T],[D,A|Tail],Rest,Score,[[D1],[A1]|Phrase]) :-
   word(d,D),
   \+ word(n,D),
   word(p,A),
   word(adj,A),!,
   D1= D,
   A1= A,
   fsa(T,Tail,Rest,Score,Phrase).

% skip determiners and mark following nouns.  this is necessary because some nouns are also verbs.
fsa([n|T],[D,N|Tail],Rest,Score,[[D1]|Phrase]) :-
    word(d,D),
    \+ word(n,D),
    word(n,N),
    D1= D,
    !,
    fsa([n|T],[n(N)|Tail],Rest,Score,Phrase).

% skip determiners
fsa([n|T],[D|Tail],Rest,Score,[[D1]|Phrase]) :-
   word(d,D),
   \+ word(n,D),
   D1= D,
   !,
   fsa([n|T],Tail,Rest,Score,Phrase).



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% any category
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fsa([X|T],[C|Tail],Rest,Score,[C2|Phrase]) :-
   find_element(X,C),
   !,
   C2= C,
   fsa(T,Tail,Rest,Score,Phrase).



% fsa is looking for a verb in -ing form, but the current word is not it.  The current word is a part of a verb phrase so move past it.
fsa([ving|T],[V|Tail],Rest,Score,[[V2]|Tl]) :-
   word(Cat,V),
   (child_of(Cat,vp)
   ;
   child_of(Cat,auxp)),!,
   V2= V,
   fsa([ving|T],Tail,Rest,Score,Tl).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% skip adjps
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% check two words out
fsa(Pattern,[Adj1,Adj2|Tail],Rest,Score,[[Adj3,Adj4]|Phrase]) :-
   word(adj,[Adj1,Adj2]),!,
   Adj3= Adj1,
   Adj4= Adj2,
   fsa(Pattern,Tail,Rest,Score,Phrase).


% the current word in the input stream is an adjective. Parse a chunk and move past it.
fsa(Pattern,[Adj|Tail],Rest,Score,[[Adj2]|Phrase]) :-
   (word(adj,Adj)
   ;
   (word(Cat,Adj),
   child_of(Cat,adjp))),!,
   Adj2= Adj,
   fsa(Pattern,Tail,Rest,Score,Phrase).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% process pps
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% The current word is a pp. it is followed by a determiner or a plural noun. skip the pp.
fsa(Pattern,[PP,D|Tail],Rest,Score,T) :-
   word(p,PP),
   (word(d,D)
   ;
   (PP \== to,
   word(n,D))
   ;
   (PP == to,
   \+ word(v,D))
   ;
   word(npl,D)
   ),!,
   parse(pp,[PP,D|Tail],Remain,Words,_),
   fsa(Pattern,[pp(Words)|Remain],Rest,Score,T).





%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% rules for skipping advps
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

/*
% the current word in the input stream is an adverb.  Parse a chunk and move past it.
% special case for verbs
fsa([vpsed|T],[V,Adv|Tail],Rest,Score,[V2,[Adv2]|Phrase]) :-
   word(v,V),
   (word(adv,Adv)
   ;
   (word(Cat,Adv),
   child_of(Cat,advp))),!,
   V2= V,
   Adv2= Adv,
   fsa(T,Tail,Rest,Score,Phrase).

*/

% 'but' is normally considered an adverb.  I can't tell whether it is or not. I have eliminated it from the lexicon.

% the current word in the input stream is an adverb.  Parse a chunk and move past it.
% don't skip adverbs that are also subordinating conjunctions.
fsa(Pattern,[Adv|Tail],Rest,Score,[[Adv2]|Phrase]) :-
   \+ word(subconj,Adv),
   (word(adv,Adv)
   ;
   (word(Cat,Adv),
   child_of(Cat,advp))),!,
   Adv2= Adv,
   fsa(Pattern,Tail,Rest,Score,Phrase).



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% unknown words
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% for now the fsa skips over unknown words. later we can make it more intelligent
fsa(Pattern,[UW|Tail],Rest,Score,[[UW2]|Phrase]) :-
   word(X,UW),
   X == unknown_word,!,
   UW2= UW,
   fsa(Pattern,Tail,Rest,Score,Phrase).

% the current word doesn't match the pattern
fsa(_,Rest,Rest,0,[]) :- !.

/*
find_element(vpl,Verb) :-
   word(vpl,Verb).


% find_element(+Element,+Target)
% succeeds if Element matches Target
find_element(vpsed,V) :-
   word(vpsed,V).


% find a verb in -ing form
find_element(ving,V) :-
   word(ving,V).
*/

% find a verb in any form
find_element(vpsed,V) :-
   word(v,V),!.

find_element(subconj,[W1,W2,W3]) :-
   ccl([W1,W2,W3],conjunction,List),
   member(subordinating,List),!.

find_element(subconj,[W1,W2]) :-
   ccl([W1,W2],conjunction,List),
   member(subordinating,List),!.

% find a subordinating conjunction
find_element(subconj,SC) :-
   ccl([SC],conjunction,List),
   member(subordinating,List),!.

find_element(n,Word) :-
   word(pronoun,Word),!.

% find a word of a particular category
find_element(Cat,Word) :-
   %Cat \== vpsed,
   word(Cat,Word),!.







child_of(a,b).






%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% miscelaneous predicates
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% simply traverses all the rules in the grammar and asserts the children of particular heads
get_children :-
   rule(X,List),
   get_children_aux(X,List),
   fail,!.

get_children.

get_children_aux(_,[]) :- !.


% optional element
get_children_aux(X,[[H]|T]) :-
   \+ child_of(H,X),
   rule(H,List),!,
   assert(child_of(H,X)),
   get_children_aux(X,List),
   get_children_aux(X,T).

get_children_aux(X,[[H]|T]) :-
   \+ child_of(H,X),
   word(H,_),!,
   assert(child_of(H,X)),
   get_children_aux(X,T).



% next element is a manditory element
get_children_aux(X,[H|T]) :-
   \+ child_of(H,X),
   rule(H,List),
   assert(child_of(H,X)),
   get_children_aux(X,List),
   get_children_aux(X,T).

get_children_aux(X,[H|T]) :-
   \+ child_of(H,X),
   word(H,_),!,
   assert(child_of(H,X)),
   get_children_aux(X,T).



get_children_aux(X,[_|T]) :-
   get_children_aux(X,T).


convert_ccl_to_list :-
   ensure_loaded('ccl.pl'),
   tell('cclalt.pl'),
   forall(ccl(X,Y,Z),(tokenize(X,Result),write(ccl(Result,Y,Z)),write('.'),nl)),
   told.

% takes in an atom that may have spaces in it and returns a list of the atoms in it
tokenize(Atom,Result) :-
   atom_chars(Atom,Chars),
   tokenize_aux(Chars,[],Result).

tokenize_aux([],List,End) :-
   atom_chars(Atom,List),
   End= [Atom].

tokenize_aux([' '|T],List,[Atom|Result]) :-
   !,
   atom_chars(Atom,List),
   tokenize_aux(T,[],Result).

tokenize_aux([H|T],Chars,Result) :-
   append(Chars,[H],CList),
   tokenize_aux(T,CList,Result).




% get subset of WordNet
get_wn_subset(OutFile,Number) :-
   ensure_loaded('c:\\active projects\\thesis\\prolog\\wn_s.pl'),
   findall((Num,Syn,Word,Cat,X),s(Num,Syn,Word,Cat,X,10),List),
   msort(List,ListS),
   reverse(ListS,ListR),
   tell(OutFile),
   print_list(ListR,Number),
   told.

print_list(_,0).
print_list([H|T],Num) :-
   write(s),write(H),write('.'),nl,
   Num2 is Num-1,
   print_list(T,Num2).




